/*
	Absztrakt Sikidom osztly
	Ha az osztly tartalmaz absztrakt metdust, akkor az osztlynak is absztraktnak kell lennie!
	Ksi kts - late binding
*/
public abstract class Sikidom implements Comparable {

	private double kerulet, terulet;
	private boolean keruletKiszamitva = false;
	private boolean teruletKiszamitva = false;

	// Figyeljk meg, hogy keruletSzamit() metdust csak ksbb deklarljuk!
	public double getKerulet() {
		if (!keruletKiszamitva) {
			kerulet = keruletSzamit();
			keruletKiszamitva = true;
		}
		return kerulet;
	}

	public double getTerulet () {
		if (!teruletKiszamitva) {
			terulet = teruletSzamit();
			teruletKiszamitva = true;
		}
		return terulet;
	}

	/*
		Most mr absztrakt metdusokat hasznlunk.
		gy sokkal elegnsabb. (Az sosztlyban mg nem tudjuk a kpletet, majd a leszrmazottban kifejtjk.)
	*/
	protected abstract double keruletSzamit();
	protected abstract double teruletSzamit();

	/*
		A Kor s a Teglalap osztlyt az absztrakt sn keresztl ksztjk fel a rendezsre.
		Meg kell adnunk, hogy egy-egy objektum 
		milyen tulajdonsga szerint hasonlthat ssze.
		A kollekci keretrendszer osztlyai a Comparable interfszt rjk el a hasonltshoz.
		Az sszehasonltst a terlet rtkei szerint definiljuk.
		Mivel az interfsz deklarcija "ltalnos" volt, a  metdusban az s (Object) tpus pldnyok szerepelnek, mint paramterek
		ezrt csak explicit tpusknyszertssel rjk el a Skidom osztly kerlet fggvnyt
	*/
	public int compareTo(Object obj) {
		double diff = getTerulet() - ((Sikidom)obj).getTerulet();
		if(diff < 0.) {
			return -1;
		} else if(diff == 0.) {
			return 0;
		} else {
			return 1;
		}
	}
}