/**
	CSV fjlok betltsre szolgl osztly.
	A beolvasott adatokat oszlopokba rendezi, s az oszlopok troljk a cellk rtkeit.
	Elre nem ismert az oszlopok szma, ezrt dinamikus tmbt alkalmazunk.
*/

import java.io.*;
import java.util.ArrayList;

public class CSV {
	private ArrayList<Oszlop> tablazat;

	public CSV() {
		tablazat = new ArrayList<Oszlop>();
	}

	/**
		A CSV fjl egy sort az elvlaszt ;-k mentn cellkra bontja.
		A cellk tartalmt egy tmbben adja vissza. tmeneti trknt ismt
		dinamikus tmbt hasznlunk, hiszen elre nem ismert a soron belli cellk szma.
		Az egyszersg kedvrt feltesszk, hogy egyik cella sem tartalmaz ;-t.
		HF: megprblni elvgezni ugyanezt a feladatot a java.util.StringTokenizer
		osztly segtsgvel!
		@param forras Az eredeti szvegsor, amit cellkra kell bontani.
		@return A soron belli cellkat tartalmaz tmb.
	*/
	private Object[] toArray(String forras) {
		ArrayList<String> al = new ArrayList<String>();
		int eleje = 0;
		int vege;
		while((vege = forras.indexOf(";", eleje)) > 0) {
			al.add(forras.substring(eleje, vege));
			eleje = vege + 1;
		}
		al.add(forras.substring(eleje));
		return al.toArray();
	}

	/**
		A fjl beolvassa.
		@param fajl A feldolgozand CSV fjl elrsi tja.
	*/
	public void readCSV(String fajl) throws IOException {
		BufferedReader f = new BufferedReader(new FileReader(fajl));
		String sor;
		tablazat.clear();
		while((sor = f.readLine()) != null) {
			Object[] tomb = toArray(sor);
			for(int i = 0; i < tomb.length; i++) {
				// Ha nincs mg olyan oszlop, amibe a cellt el lehetne helyezni, ltrehozzuk.
				if (i == tablazat.size()) {
					tablazat.add(new Oszlop());
				}
				tablazat.get(i).addSor((String)tomb[i]);
			}
		}
		f.close();
	}

	/** A tblzat adatainak megjelentse. Csak konzolon, monospace bettpussal lesz szp a formzs. */
	public void printCSV() {
		if (tablazat.size() > 0) {
			StringBuffer formatum = new StringBuffer();
			int sorok = tablazat.get(0).getCellaDb();
			for(int i = 0; i < sorok; i++) {
				for(int j = 0; j < tablazat.size(); j++) {
					// A formtumsztringet is futs kzben lltjuk el
					System.out.format("%" + tablazat.get(j).getSzelesseg() + "s ",
						tablazat.get(j).getCella(i));
				}
				System.out.println();
			}
		}
	}
}